<?php
  /*
   * @author 		Marc Sven Kleinboehl (aka Hroudtwolf)
   * @copyright 	GNU Public License.
   */

  class classload_cachedriver_drupal implements classload_cachedriver {
    
    private $cache;
    
    /*
     * Implements classload_cachedriver->init ().
     */
    public function init () {
      
      $cache_entry = cache_get ('classload_cache');
 
      if ($cache_entry != 0) {
        
        $this->cache = $cache_entry->data;
        return;
      }
      
      
      $this->cache = classload_cache::load_classes_directory ();
 
      cache_set ('classload_cache', $this->cache);
      
      return;
    }
    
    /*
     * Implements classload_cachedriver->load ().
     */
    public function load ($class_name) {
      
      if (!isset ($this->cache[$class_name]) || !file_exists ($this->cache[$class_name])) {
        
        return false;
      }
      
      require_once $this->cache[$class_name];
      
      return true;
    }   
    
    /*
     * Implements classload_cachedriver->class_file_exists ().
     */
    public function class_file_exists ($class_name) {
      
      return isset ($this->cache[$class_name]) && 
             file_exists($this->cache[$class_name]);
    }
    
    /*
     * Implements classload_cachedriver->get_settings_description ().
     */
    public function get_settings_description () {
      
      return t('By default, drupal caches into the database.');
    }
    
    /*
     * Implements classload_cachedriver->reset  ().
     */
    public function reset () {
      
      cache_clear_all ('classload_cache', 'cache');
      
      return;
    }
  }