<?php
  /*
   * @author 		Marc Sven Kleinboehl (aka Hroudtwolf)
   * @copyright 	GNU Public License.
   */

  class classload_cachedriver_filesys implements classload_cachedriver {
          
    private $cache;
    
    /*
     * Implements classload_cachedriver->init ().
     */
    public function init () {
      
      $cache_file_path = drupal_get_path ('module', 'classload') . '/cache/cache.tmp';
      $cache_entry     = false;
      
      if (file_exists ($cache_file_path)) {
        $cache_entry = file_get_contents($cache_file_path);
      }
 
      if ($cache_entry != false) {
        
        $this->cache = unserialize ($cache_entry);
        return;
      }

      $this->cache = classload_cache::load_classes_directory ();

      file_put_contents($cache_file_path, serialize ($this->cache));
      
      return;
    }
    
    /*
     * Implements classload_cachedriver->load  ().
     */
    public function load ($class_name) {
      
      if (!isset ($this->cache[$class_name]) || !file_exists ($this->cache[$class_name])) {
        
        return false;
      }
      
      require_once $this->cache[$class_name];
      
      return true;
    }   
    
    /*
     * Implements classload_cachedriver->class_file_exists  ().
     */
    public function class_file_exists ($class_name) {
      
      return isset ($this->cache[$class_name]) && 
             file_exists($this->cache[$class_name]);
    }
    
    /*
     * Implements classload_cachedriver->get_settings_description ().
     */
    public function get_settings_description () {
      
      return t('Ensure that the cache folder in the "classload" directory has write permissions.');
    }
    
    /*
     * Implements classload_cachedriver->reset ().
     */
    public function reset () {
      
      $cache_file_path = drupal_get_path ('module', 'classload') . '/cache/cache.tmp';
      
      file_delete($cache_file_path);
      
      return;
    }
  }