<?php
  /*
   * @author 		Marc Sven Kleinboehl (aka Hroudtwolf)
   * @copyright 	GNU Public License.
   * @details		
   */

  module_load_include('inc', 'classload', 'includes/classload_cachedriver.interface.inc');
  
  class classload_cache {

    private static $classes_path  = null;
    private static $cache_driver  = null;
    
    /*
     * Initializes the caching method.
     */
    private static function init () {
      
      $cache_driver_name = 'classload_cachedriver_' . variable_get ('classload_cachedriver', 'drupal');
      
      module_load_include('inc', 'classload', 'includes/classload_cachedriver.interface');
      module_load_include('inc', 'classload', 'includes/cachedrivers/' . $cache_driver_name . '.class');

      self::$cache_driver = new $cache_driver_name ();
      self::$cache_driver->init ();

      return;
    }
    
    /*
     * Loads the class per its name.
     * @param string $class_name The name of the class.
     */
    public static function load ($class_name) {
      
      if (self::$cache_driver == null) {
        self::init ();
      }
      
      self::$cache_driver->load ($class_name);
      
      return;
    }
    
    /*
     * Retrieves the full path of the "classes" folder.
     * @return string A string which contains a path.
     */
    public static function get_classes_path () {

      if (self::$classes_path == null) {
        self::$classes_path = 'sites/all/classes';
      }

      return self::$classes_path;
    }

    /*
     * Checks whether a class exists in a specific class file.
     * @param string 	$class_name The name of the class.
     * @param string 	$file_path The full path of the class file.
     * @return boolean 	TRUE on success.
     */
    private static function classfile_contains_class ($class_name, $file_path) {
     
      $content = file_get_contents ($file_path);
      if (!$content) return false;
      
      $result  = strpos($content, 'class ' . $class_name);
      if (!$result) {
        
        $result  = strpos($content, 'interface ' . $class_name);
      }
      
      unset ($content);
      
      return !(!$result);
    }
    
    /*
     * Loads the class files recursively from "classes" directory.
     * FOR INTERNAL USE ONLY!
     */
    private static function load_classes_directory_recursivly (&$entries, $path) {
       
      $directory = dir($path);
      
      if (!empty($directory)) {
        while (false !== ($entry = $directory->read())) {
          
          $file_path = $path .'/' . $entry;
       
           if ($entry[0] != '.') {               
             if (is_file ($file_path)) {
               
               $path_parts     = pathinfo($entry);
               $class_name     = basename($entry, '.' . $path_parts["extension"]);
               
               if (self::classfile_contains_class ($class_name, $file_path)) {
                 $entries[$class_name] = $file_path;
               }
               
               unset ($path_parts);
             }else{
               self::load_classes_directory_recursivly ($entries, $file_path);
             }
           }
        }
        $directory->close();
      }
      
      return;
    }

    /*
     * Loads the class files recursively from "classes" directory.
     * @return array An array which contains found class files.
     */
    public static function load_classes_directory () {
      
      $entries = array ();      

      self::load_classes_directory_recursivly ($entries, self::get_classes_path ());
      
      module_invoke_all ('classes_detected', $entries);
      
      return $entries;
    }
    
    /*
     * Retrieves the description text of the current cache method.
     * @return string A string which contains a description text.
     */
    public static function get_cache_method_settings_description () {
      
 
      return self::$cache_driver->get_settings_description ();
    }
    
    /*
     * Resets the current cache method.
     */
    public static function reset_cache_method () {
       
      self::$cache_driver->reset ();
      
      return;
    }
  }
